@@ -1,9 +1,9 @@
-#-----------------------------------------------------------------------------#
+# --------------------------------------------------------------------------- #
 #   __init__.py                                                               #
 #                                                                             #
-#   Copyright © 2015-2018, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
-#-----------------------------------------------------------------------------#
+# --------------------------------------------------------------------------- #
 '''Redis for Humans.
 
 Redis is awesome, but Redis commands are not always fun.  Pottery is a Pythonic
@@ -12,9 +12,8 @@ know how to use Pottery.
 '''
 
 
-
 __title__ = 'pottery'
-__version__ = '0.52'
+__version__ = '0.72'
 __description__, __long_description__ = (
     s.strip() for s in __doc__.split(sep='\n\n', maxsplit=1)
 )
@@ -23,25 +22,24 @@ __author__ = 'Rajiv Bakulesh Shah'
 __author_email__ = 'brainix@gmail.com'
 __license__ = 'Apache 2.0'
 __keywords__ = 'Redis client persistent storage'
-__copyright__ = 'Copyright © 2015-2018, {}, original author.'.format(__author__)
+__copyright__ = 'Copyright © 2015-2020, {}, original author.'.format(__author__)
 
 
+from .exceptions import PotteryError  # isort:skip
+from .exceptions import KeyExistsError  # isort:skip
+from .exceptions import RandomKeyError  # isort:skip
+from .exceptions import PrimitiveError  # isort:skip
+from .exceptions import QuorumNotAchieved  # isort:skip
+from .exceptions import TooManyExtensions  # isort:skip
+from .exceptions import ReleaseUnlockedLock  # isort:skip
 
-from .exceptions import PotteryError
-from .exceptions import KeyExistsError
-from .exceptions import RandomKeyError
-from .exceptions import PrimitiveError
-from .exceptions import QuorumNotAchieved
-from .exceptions import TooManyExtensions
-from .exceptions import ReleaseUnlockedLock
-
-from .bloom import BloomFilter
-from .cache import CachedOrderedDict
-from .cache import redis_cache
-from .hyper import HyperLogLog
-from .nextid import NextId
-from .redlock import Redlock
-from .timer import ContextTimer
+from .bloom import BloomFilter  # isort:skip
+from .cache import CachedOrderedDict  # isort:skip
+from .cache import redis_cache  # isort:skip
+from .hyper import HyperLogLog  # isort:skip
+from .nextid import NextId  # isort:skip
+from .redlock import Redlock  # isort:skip
+from .timer import ContextTimer  # isort:skip
 
 from .counter import RedisCounter
 from .deque import RedisDeque
@@ -50,7 +48,6 @@ from .list import RedisList
 from .set import RedisSet
 
 
-
 __all__ = [
     'PotteryError',
     'KeyExistsError',
