@@ -1,10 +1,9 @@
-#-----------------------------------------------------------------------------#
+# --------------------------------------------------------------------------- #
 #   deque.py                                                                  #
 #                                                                             #
-#   Copyright © 2015-2018, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
-#-----------------------------------------------------------------------------#
-
+# --------------------------------------------------------------------------- #
 
 
 import collections
@@ -12,7 +11,6 @@ import collections
 from .list import RedisList
 
 
-
 class RedisDeque(RedisList, collections.deque):
     'Redis-backed container compatible with collections.deque.'
 
@@ -20,19 +18,10 @@ class RedisDeque(RedisList, collections.deque):
 
     def __init__(self, iterable=tuple(), maxlen=None, *, redis=None, key=None):
         'Initialize a RedisDeque.  O(n)'
+        if maxlen is not None and not isinstance(maxlen, int):
+            raise TypeError('an integer is required')
         self._maxlen = maxlen
         super().__init__(iterable, redis=redis, key=key)
-
-    def _populate(self, iterable=tuple()):
-        if self.maxlen is not None:
-            try:
-                if self.maxlen:
-                    iterable = tuple(iterable)[-self.maxlen:]
-                else:
-                    iterable = tuple()
-            except TypeError:
-                raise TypeError('an integer is required')
-        super()._populate(iterable)
         if not iterable and self.maxlen is not None and len(self) > self.maxlen:
             raise IndexError(
                 'persistent {} beyond its maximum size'.format(
@@ -40,6 +29,14 @@ class RedisDeque(RedisList, collections.deque):
                 ),
             )
 
+    def _populate(self, iterable=tuple()):
+        if self.maxlen is not None:
+            if self.maxlen:
+                iterable = tuple(iterable)[-self.maxlen:]
+            else:  # pragma: no cover
+                iterable = tuple()
+        super()._populate(iterable)
+
     @property
     def maxlen(self):
         return self._maxlen
@@ -78,7 +75,7 @@ class RedisDeque(RedisList, collections.deque):
 
     def extendleft(self, values):
         '''Extend a RedisList by prepending elements from the iterable.  O(1)
-        
+
         Note the order in which the elements are prepended from the iterable:
 
             >>> d = RedisDeque()
