@@ -1,10 +1,9 @@
-#-----------------------------------------------------------------------------#
+# --------------------------------------------------------------------------- #
 #   exceptions.py                                                             #
 #                                                                             #
-#   Copyright © 2015-2018, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
-#-----------------------------------------------------------------------------#
-
+# --------------------------------------------------------------------------- #
 
 
 class PotteryError(Exception):
@@ -31,6 +30,9 @@ class KeyExistsError(PotteryError):
 class RandomKeyError(PotteryError, RuntimeError):
     "Can't create a random Redis key; all of our attempts already exist."
 
+    def __init__(self, redis):
+        super().__init__(redis, None)
+
     def __repr__(self):
         return "{}(redis={})".format(self.__class__.__name__, self._redis)
 
@@ -38,7 +40,6 @@ class RandomKeyError(PotteryError, RuntimeError):
         return 'redis={}'.format(self._redis)
 
 
-
 class PrimitiveError(Exception):
     'Base exception class for distributed primitives.'
 
