@@ -1,10 +1,9 @@
-#-----------------------------------------------------------------------------#
+# --------------------------------------------------------------------------- #
 #   set.py                                                                    #
 #                                                                             #
-#   Copyright © 2015-2018, Rajiv Bakulesh Shah, original author.              #
+#   Copyright © 2015-2020, Rajiv Bakulesh Shah, original author.              #
 #   All rights reserved.                                                      #
-#-----------------------------------------------------------------------------#
-
+# --------------------------------------------------------------------------- #
 
 
 import collections.abc
@@ -15,19 +14,19 @@ from .base import Iterable
 from .exceptions import KeyExistsError
 
 
-
 class RedisSet(Base, Iterable, collections.abc.MutableSet):
     'Redis-backed container compatible with Python sets.'
 
     def __init__(self, iterable=tuple(), *, redis=None, key=None):
         'Initialize a RedisSet.  O(n)'
         super().__init__(iterable, redis=redis, key=key)
-        with self._watch(iterable):
-            self._populate(iterable)
+        if iterable:
+            with self._watch(iterable):
+                self._populate(iterable)
 
     def _populate(self, iterable=tuple()):
         encoded_values = {self._encode(value) for value in iterable}
-        if encoded_values:
+        if encoded_values:  # pragma: no cover
             if self.redis.exists(self.key):
                 raise KeyExistsError(self.redis, self.key)
             else:
@@ -92,27 +91,27 @@ class RedisSet(Base, Iterable, collections.abc.MutableSet):
         return disjoint
 
     # Where does this method come from?
-    def issubset(self, other):                      # pragma: no cover
+    def issubset(self, other):  # pragma: no cover
         raise NotImplementedError
 
     # Where does this method come from?
-    def issuperset(self, other):                    # pragma: no cover
+    def issuperset(self, other):  # pragma: no cover
         raise NotImplementedError
 
     # Where does this method come from?
-    def union(self, *args):                         # pragma: no cover
+    def union(self, *args):  # pragma: no cover
         raise NotImplementedError
 
     # Where does this method come from?
-    def intersection(self, *args):                  # pragma: no cover
+    def intersection(self, *args):  # pragma: no cover
         raise NotImplementedError
 
     # Where does this method come from?
-    def difference(self, *args):                    # pragma: no cover
+    def difference(self, *args):  # pragma: no cover
         raise NotImplementedError
 
     # Where does this method come from?
-    def symmetric_difference(self, other):          # pragma: no cover
+    def symmetric_difference(self, other):  # pragma: no cover
         raise NotImplementedError
 
     def _update(self, *iterables, redis_method):
@@ -130,7 +129,7 @@ class RedisSet(Base, Iterable, collections.abc.MutableSet):
         self._update(*iterables, redis_method='sadd')
 
     # Where does this method come from?
-    def intersection_update(self, *args):           # pragma: no cover
+    def intersection_update(self, *args):  # pragma: no cover
         raise NotImplementedError
 
     # Where does this method come from?
@@ -138,5 +137,5 @@ class RedisSet(Base, Iterable, collections.abc.MutableSet):
         self._update(*iterables, redis_method='srem')
 
     # Where does this method come from?
-    def symmetric_difference_update(self, other):   # pragma: no cover
+    def symmetric_difference_update(self, other):  # pragma: no cover
         raise NotImplementedError
